{************************************************************
****            Sega-Zero Gradient Library               ****
****                                                     ****
****               Status: Freeware.                     ****
****                                                     ****
****      :        ****
****       ,    ****
****      ""  ,    -  ****
****     .     -    ****
****     .  -   ,    ****
****       (  -   - ****
****      )      ****
****          .   -  ****
****       ,   .  , ****
****          - ****
****         .      ****  
************************************************************}
unit SegaGradients;

interface
uses
  Windows, SysUtils, Graphics, Classes;

type
 TColorArray = array of TColor;

procedure ComplexFillArray(Colors: array of TColor;
                           var ColorArray: TColorArray;
                           ArrayWidth: Integer);

procedure SimpleFillArray(FromColor, ToColor: TColor;
                          var ColorArray: TColorArray;
                          ArrayWidth: Integer);

//    
function ArrayMirror(Colors:TColorArray):TColorArray;

function Max(First, Last: Integer): Integer;
function Min(First, Last: Integer): Integer;

function CirclesArrayWidth(FillRect: TRect): Integer;
function EnvelopeArrayWidth(FillRect: TRect): Integer;
function HorizontalArrayWidth(FillRect: TRect): Integer;
function VerticalArrayWidth(FillRect: TRect): Integer;
function LeftRightPiesArrayWidth(FillRect: TRect): Integer;
function TopBottomPiesArrayWidth(FillRect: TRect): Integer;
function DiagonalArrayWidth(FillRect: TRect): Integer;
function DiamondArrayWidth(FillRect: TRect): Integer;
function RoundStarArrayWidth(FillRect: TRect): Integer;
function HorWaveArrayWidth(FillRect: TRect): Integer;
function VertWaveArrayWidth(FillRect: TRect): Integer;
function StarArrayWidth(FillRect: TRect): Integer;
function TopLeftFanArrayWidth(FillRect: TRect): Integer;
function TopRightFanArrayWidth(FillRect: TRect): Integer;
function BottomLeftFanArrayWidth(FillRect: TRect): Integer;
function BottomRightFanArrayWidth(FillRect: TRect): Integer;

procedure CirclesGradient(Canvas: TCanvas;
                          FillRect: TRect;
                          Colors: TColorArray);

procedure EnvelopeGradient(Canvas: TCanvas;
                           FillRect: TRect;
                           Colors: TColorArray);

procedure HorizontalGradient(Canvas: TCanvas;
                             FillRect: TRect;
                             Colors: TColorArray);

procedure VerticalGradient(Canvas: TCanvas;
                           FillRect: TRect;
                           Colors: TColorArray);

procedure LeftRightPiesGradient(Canvas: TCanvas;
                                FillRect: TRect;
                                Colors: TColorArray);

procedure TopBottomPiesGradient(Canvas: TCanvas;
                                FillRect: TRect;
                                Colors: TColorArray);

procedure TopLeftDiagGradient(Canvas: TCanvas;
                              FillRect: TRect;
                              Colors: TColorArray);

procedure TopRightDiagGradient(Canvas: TCanvas;
                               FillRect: TRect;
                               Colors: TColorArray);

procedure DiamondGradient(Canvas: TCanvas;
                          FillRect: TRect;
                          Colors: TColorArray);

procedure RoundStarGradient(Canvas: TCanvas;
                            FillRect: TRect;
                            Colors: TColorArray);

procedure HorWaveGradient(Canvas: TCanvas;
                          FillRect: TRect;
                          Colors: TColorArray;
                          Frequency: Real = 0.01);

procedure VertWaveGradient(Canvas: TCanvas;
                           FillRect: TRect;
                           Colors: TColorArray;
                           Frequency: Real = 0.01);

procedure StarGradient(Canvas: TCanvas;
                       FillRect: TRect;
                       Colors: TColorArray);

procedure TopLeftFanGradient(Canvas: TCanvas;
                             FillRect: TRect;
                             Colors: TColorArray);

procedure TopRightFanGradient(Canvas: TCanvas;
                              FillRect: TRect;
                              Colors: TColorArray);

procedure BottomLeftFanGradient(Canvas: TCanvas;
                                FillRect: TRect;
                                Colors: TColorArray);  

procedure BottomRightFanGradient(Canvas: TCanvas;
                                 FillRect: TRect;
                                 Colors: TColorArray);

implementation

function Max(First, Last: Integer): Integer;
begin
Result:=First;
if Result <  Last then Result:=Last;
end;

function Min(first, last: Integer): Integer;
begin
Result := First;
if Result > Last then Result := Last;
end;

procedure SimpleFillArray(FromColor, ToColor: TColor;
                          var ColorArray: TColorArray;
                          ArrayWidth: Integer);
var
  i: Integer;
  R1,G1,B1,
  R2,G2,B2: Byte;
begin
  R1 := GetRValue(ColorToRGB(FromColor));
  G1 := GetGValue(ColorToRGB(FromColor));
  B1 := GetBValue(ColorToRGB(FromColor));
  R2 := GetRValue(ColorToRGB(ToColor));
  G2 := GetGValue(ColorToRGB(ToColor));
  B2 := GetBValue(ColorToRGB(ToColor));

  for i:=0 to ArrayWidth do
ColorArray[i]:=RGB(R1 - i*(R1 - R2) div ArrayWidth,
                   G1 - i*(G1 - G2) div ArrayWidth,
                   B1 - i*(B1 - B2) div ArrayWidth);
end;

procedure ComplexFillArray(Colors: array of TColor;
                           var ColorArray: TColorArray;
                           ArrayWidth: Integer);
var ColArray: TColorArray;
    i,j,Temp: Integer;
    Equal: Boolean;
begin
//   
//  :
if High(Colors) < 0 then
   begin
     raise Exception.Create('Specify at least one color!');
     Exit;
   end;

//   , 
//    :
if High(Colors) = 0 then
   begin
    for i := 0 to ArrayWidth do
        ColorArray[i] := Colors[0];
    Exit;    
   end;

Temp:=ArrayWidth div (High(Colors));//  
SetLength(ColArray,Temp + 1);
Equal:=(ArrayWidth mod Temp)=0;//  - 
                               //  

 for i := 0 to High(Colors) - 1 do
   begin
     SimpleFillArray(Colors[i],
                     Colors[i + 1],
                     ColArray,
                     Temp);
     for j := 0 to Temp do
         ColorArray[j + i*Temp] := ColArray[j];
   end;
//    ,   :
//     ArrayWidth mod Temp   
//      
if not Equal then begin
SimpleFillArray(ColorArray[ArrayWidth - ArrayWidth mod Temp],
                Colors[High(Colors)],
                ColArray,
                ArrayWidth mod Temp);
    j := 0;
for i := ArrayWidth - ArrayWidth mod Temp
    to ArrayWidth do begin
                       ColorArray[i] := ColArray[j];
                       inc(j);
                     end;
                  end;
Finalize(ColArray);
end;

function ArrayMirror(Colors:TColorArray):TColorArray;
var i: Integer;
    ColArray: TColorArray;
begin
 SetLength(ColArray,High(Colors) + 1);

 for i := 0 to High(Colors) do
   ColArray[High(ColArray)-i] := Colors[i];

 Result:=ColArray;
 Finalize(ColArray);
end;

// Array Width Calculating Functions
function CirclesArrayWidth(FillRect: TRect): Integer;
var Width, Height, minus: Integer;
begin
Width  := abs(FillRect.Right - FillRect.Left);
Height := abs(FillRect.Bottom - FillRect.Top);
minus  := 15*(Width + Height) div Min(Width, Height);
Result := Min(Width, Height) div 2+minus;
end;

function EnvelopeArrayWidth(FillRect: TRect): Integer;
var Width, Height: Integer;
begin
Width  := abs(FillRect.Right - FillRect.Left);
Height := abs(FillRect.Bottom - FillRect.Top);
Result := Min(Width,Height) div 2;
end;

function HorizontalArrayWidth(FillRect: TRect): Integer;
begin
 Result := abs(FillRect.Bottom - FillRect.Top);
end;

function VerticalArrayWidth(FillRect: TRect): Integer;
begin
 Result := abs(FillRect.Right - FillRect.Left);
end;

function LeftRightPiesArrayWidth(FillRect: TRect): Integer;
begin
 Result := VerticalArrayWidth(FillRect) div 2;
end;

function TopBottomPiesArrayWidth(FillRect: TRect): Integer;
begin
 Result := HorizontalArrayWidth(FillRect) div 2;
end;

function DiagonalArrayWidth(FillRect: TRect): Integer;
begin
 Result := VerticalArrayWidth(FillRect) +
           HorizontalArrayWidth(FillRect);
end;

function DiamondArrayWidth(FillRect: TRect): Integer;
begin
  Result := EnvelopeArrayWidth(FillRect);
end;

function RoundStarArrayWidth(FillRect: TRect): Integer;
begin
 Result := EnvelopeArrayWidth(FillRect);
end;

function HorWaveArrayWidth(FillRect: TRect): Integer;
begin
 Result := HorizontalArrayWidth(FillRect);
end;

function VertWaveArrayWidth(FillRect: TRect): Integer;
begin
 Result := VerticalArrayWidth(FillRect);
end;

function StarArrayWidth(FillRect: TRect): Integer;
begin
 Result := 2*Min(HorizontalArrayWidth(FillRect),
                 VerticalArrayWidth(FillRect)) div 3;
end;

function TopLeftFanArrayWidth(FillRect: TRect): Integer;
begin
 Result := HorizontalArrayWidth(FillRect) +
           VerticalArrayWidth(FillRect);
end;

function TopRightFanArrayWidth(FillRect: TRect): Integer;
begin
 Result := HorizontalArrayWidth(FillRect) +
           VerticalArrayWidth(FillRect);
end;

function BottomLeftFanArrayWidth(FillRect: TRect): Integer;
begin
 Result := HorizontalArrayWidth(FillRect) +
           VerticalArrayWidth(FillRect);
end;

function BottomRightFanArrayWidth(FillRect: TRect): Integer;
begin
 Result := HorizontalArrayWidth(FillRect) +
           VerticalArrayWidth(FillRect);
end;

// Gradient functions :
procedure CirclesGradient(Canvas: TCanvas;
                          FillRect: TRect;
                          Colors: TColorArray);
var i,Minus: Integer;
    TempBmp:TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);
Minus := 15*(TempBmp.Width + TempBmp.Height)
         div Min(TempBmp.Width, TempBmp.Height);
try
    With TempBmp do begin
        Canvas.Brush.Color := Colors[0];
        Canvas.FillRect(FillRect);
        for i := 0 to CirclesArrayWidth(FillRect) do
           begin
        Canvas.Pen.Color   := Colors[i];
        Canvas.Brush.Color := Colors[i];
        Canvas.Ellipse(Rect(i - Minus,
                            i - Minus,
                            TempBmp.Width - i + Minus,
                            TempBmp.Height - i + Minus));
           end;
                     end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
  TempBmp.Free;
end;
end;

procedure EnvelopeGradient(Canvas: TCanvas;
                           FillRect: TRect;
                           Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
With TempBmp do
for i := 0 to EnvelopeArrayWidth(FillRect) do
    begin
      Canvas.Brush.Color := Colors[i];
      Canvas.FillRect(Rect(i,
                           i,
                           TempBmp.Width - i,
                           TempBmp.Height - i));
    end;
Canvas.StretchDraw(FillRect, TempBmp);
finally
  TempBmp.Free;
end;
end;

procedure HorizontalGradient(Canvas: TCanvas;
                             FillRect: TRect;
                             Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
    With TempBmp do
    for i := 0 to TempBmp.Height do
       begin
         Canvas.Pen.Color := Colors[i];
         Canvas.MoveTo( - 1, i);
         Canvas.LineTo(TempBmp.Width + 1, i);
       end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
  TempBmp.Free;
end;
end;

procedure VerticalGradient(Canvas: TCanvas;
                           FillRect: TRect;
                           Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
    With TempBmp do
    for i := 0 to TempBmp.Width do
       begin
         Canvas.Pen.Color := Colors[i];
         Canvas.MoveTo(i, - 1);
         Canvas.LineTo(i, TempBmp.Height);
       end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure LeftRightPiesGradient(Canvas: TCanvas;
                                FillRect: TRect;
                                Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
With TempBmp do begin
Canvas.Brush.Color := Colors[0];
Canvas.FillRect(FillRect);

for i := 0 to TempBmp.Width div 2  do
  begin
    Canvas.Pen.Color   := Colors[i];
    Canvas.Brush.Color := Colors[i];
    Canvas.Pie(- TempBmp.Width div 2,
               0,
               (TempBmp.Width div 2) - i,
               TempBmp.Height,
               0,
               TempBmp.Height,
               0,
               0);
    Canvas.Pie((TempBmp.Width div 2) + i,
               0,
               3*TempBmp.Width div 2,
               TempBmp.Height,
               TempBmp.Width,
               0,
               TempBmp.Width,
               TempBmp.Height);
  end;
                end;
Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure TopBottomPiesGradient(Canvas: TCanvas;
                                FillRect: TRect;
                                Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
With TempBmp do begin
Canvas.Brush.Color := Colors[0];
Canvas.FillRect(FillRect);
for i := 0 to TempBmp.Height div 2  do
  begin
    Canvas.Pen.Color   := Colors[i];
    Canvas.Brush.Color := Colors[i];
    Canvas.Pie(0,
               - (TempBmp.Height div 2),
               TempBmp.Width,
               (TempBmp.Height div 2) - i,
               0,
               0,
               TempBmp.Width,
               0);

    Canvas.Pie(0,
               (TempBmp.Height div 2)+i,
               TempBmp.Width,
               3*(TempBmp.Height div 2),
               0,
               0,
               0,
               0);
  end;
                                  end;
Canvas.StretchDraw(FillRect,TempBmp);
finally
TempBmp.Free;
end;
end;

procedure TopLeftDiagGradient(Canvas: TCanvas;
                              FillRect: TRect;
                              Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
    With TempBmp do
    for i := DiagonalArrayWidth(FillRect) downto 0 do
        begin
          Canvas.MoveTo(0, i);
          Canvas.Pen.Color:=Colors[i];
          Canvas.LineTo(i, - 1);
        end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure TopRightDiagGradient(Canvas: TCanvas;
                               FillRect: TRect;
                               Colors: TColorArray);
var i: Integer;
    TempBmp:TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
    With TempBmp do
    for i := DiagonalArrayWidth(FillRect) downto 0 do
        begin
          Canvas.MoveTo(TempBmp.Width,
                        DiagonalArrayWidth(FillRect) - i);
          Canvas.Pen.Color:=Colors[DiagonalArrayWidth(FillRect) - i];
          Canvas.LineTo(i - TempBmp.Height, - 1);
        end;
    Canvas.StretchDraw(FillRect,TempBmp);
finally
TempBmp.Free;
end;
end;

procedure DiamondGradient(Canvas: TCanvas;
                          FillRect: TRect;
                          Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
With TempBmp do
begin
  Canvas.Brush.Color := Colors[0];
  Canvas.FillRect(TempBmp.Canvas.ClipRect);
  for i:=0 to DiamondArrayWidth(FillRect) do
    begin
     Canvas.Pen.Color := Colors[i];
     Canvas.MoveTo(i, TempBmp.Height div 2);
     Canvas.LineTo(TempBmp.Width div 2, i);
     Canvas.LineTo(TempBmp.Width - i, TempBmp.Height div 2);
     Canvas.LineTo(TempBmp.Width div 2, TempBmp.Height - i);
     Canvas.LineTo(i, TempBmp.Height div 2);
    end;
end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure RoundStarGradient(Canvas: TCanvas;
                       FillRect: TRect;
                       Colors: TColorArray);
var i, Differ: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

Differ := Max(TempBmp.Width,TempBmp.Height) -
          Min(TempBmp.Width,TempBmp.Height) div 2;

try
With TempBmp do
begin
Canvas.Brush.Color := Colors[0];
Canvas.FillRect(FillRect);

  for i := 0 to RoundStarArrayWidth(FillRect) do
    begin
     Canvas.Pen.Color := Colors[i];
     Canvas.MoveTo(i + Differ, TempBmp.Height div 2);
     Canvas.LineTo(TempBmp.Width div 2, i);
     Canvas.LineTo(TempBmp.Width - i - Differ, TempBmp.Height div 2);
     Canvas.LineTo(TempBmp.Width div 2, TempBmp.Height - i);
     Canvas.LineTo(i + Differ, TempBmp.Height div 2);
    end;
end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure HorWaveGradient(Canvas: TCanvas;
                          FillRect: TRect;
                          Colors: TColorArray;
                          Frequency: Real);
var i: Integer;
    TempBmp,LineBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

LineBmp        := TBitmap.Create;
LineBmp.Width  := 1;
LineBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
HorizontalGradient(LineBmp.Canvas,
                   LineBmp.Canvas.ClipRect,
                   Colors);
With TempBmp do
begin
Canvas.Brush.Color:=Colors[0];
Canvas.FillRect(Rect(0,0,
                     TempBmp.Width,
                     TempBmp.Height div 2));

Canvas.Brush.Color:=Colors[High(Colors)];
Canvas.FillRect(Rect(0,TempBmp.Height div 2,
                     TempBmp.Width,TempBmp.Height));

for i := 0 to TempBmp.Width do
  TempBmp.Canvas.Draw(i,Round(50*sin(Frequency*i)),LineBmp);

end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
LineBmp.Free;
end;
end;

procedure VertWaveGradient(Canvas: TCanvas;
                           FillRect: TRect;
                           Colors: TColorArray;
                           Frequency: Real);
var i: Integer;
    TempBmp,LineBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

LineBmp        := TBitmap.Create;
LineBmp.Width  := abs(FillRect.Right - FillRect.Left);
LineBmp.Height := 1;

try
VerticalGradient(LineBmp.Canvas,
                 LineBmp.Canvas.ClipRect,
                 Colors);
With TempBmp do
begin
Canvas.Brush.Color := Colors[0];
Canvas.FillRect(Rect(0,0,
                     TempBmp.Width div 2,
                     TempBmp.Height));

Canvas.Brush.Color := Colors[High(Colors)];
Canvas.FillRect(Rect(TempBmp.Width div 2, 0,
                     TempBmp.Width, TempBmp.Height));

for i := 0 to TempBmp.Height do
TempBmp.Canvas.Draw(Round(50*sin(Frequency*i)), i, LineBmp);

end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
LineBmp.Free;
end;
end;

procedure StarGradient(Canvas: TCanvas;
                       FillRect: TRect;
                       Colors: TColorArray);
var i,Radius: Integer;
    Center,
    TopVertex, LeftVertex, RightVertex,
    LeftBottomVertex, RightBottomVertex: TPoint;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

Radius := StarArrayWidth(FillRect);
Center := Point(TempBmp.Width div 2, TempBmp.Height div 2);

try
With TempBmp do
begin
  Canvas.Brush.Color := Colors[0];
  Canvas.FillRect(TempBmp.Canvas.ClipRect);
  for i := 0 to StarArrayWidth(FillRect) do
    begin
Canvas.Pen.Color  := Colors[i];

TopVertex         := Point(Center.X,Center.Y - Radius);

LeftVertex        := Point(Center.X - Round(Radius/cos(pi/10)){18 },
                           Center.Y - Round(Radius*sin(pi/10)/cos(pi/10)));

RightVertex       := Point(Center.X + Round(Radius/cos(pi/10)),
                           Center.Y - Round(Radius*sin(pi/10)/cos(pi/10)));

LeftBottomVertex  := Point(Center.X - Round(Radius/sqrt(2)),
                           Center.Y + Round(Radius/sqrt(2)));

RightBottomVertex := Point(Center.X + Round(Radius/sqrt(2)),
                           Center.Y + Round(Radius/sqrt(2)));

Canvas.Polyline([TopVertex,
                 LeftBottomVertex,
                 RightVertex,
                 LeftVertex,
                 RightBottomVertex,
                 TopVertex]);
dec(Radius);
    end;
end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure TopLeftFanGradient(Canvas: TCanvas;
                             FillRect: TRect;
                             Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
With TempBmp do
begin
  for i := 0 to TempBmp.Width do
    begin
      Canvas.Pen.Color:=Colors[i];
      Canvas.MoveTo(0, 0);
      Canvas.LineTo(i, TempBmp.Height);
    end;
  for i := 0 to TempBmp.Height do
    begin
      Canvas.Pen.Color:=Colors[i + TempBmp.Width];
      Canvas.MoveTo(0,0);
      Canvas.LineTo(TempBmp.Width, TempBmp.Height - i);
    end;
end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure TopRightFanGradient(Canvas: TCanvas;
                              FillRect: TRect;
                              Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
With TempBmp do
begin
  for i := 0 to TempBmp.Width do
    begin
      Canvas.Pen.Color:=Colors[i];
      Canvas.MoveTo(TempBmp.Width,0);
      Canvas.LineTo(TempBmp.Width - i, TempBmp.Height);
    end;
  for i := 0 to TempBmp.Height do
    begin
      Canvas.Pen.Color:=Colors[i + TempBmp.Width];
      Canvas.MoveTo(TempBmp.Width, 0);
      Canvas.LineTo(-1, TempBmp.Height - i);
    end;
end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure BottomLeftFanGradient(Canvas: TCanvas;
                                FillRect: TRect;
                                Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
With TempBmp do
begin
  for i := 0 to TempBmp.Width do
    begin
      Canvas.Pen.Color:=Colors[i];
      Canvas.MoveTo(0, TempBmp.Height);
      Canvas.LineTo(i, -1);
    end;
  for i := 0 to TempBmp.Height do
    begin
      Canvas.Pen.Color:=Colors[i + TempBmp.Width];
      Canvas.MoveTo(0, TempBmp.Height);
      Canvas.LineTo(TempBmp.Width, i);
    end;
end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

procedure BottomRightFanGradient(Canvas: TCanvas;
                                 FillRect: TRect;
                                 Colors: TColorArray);
var i: Integer;
    TempBmp: TBitmap;
begin
TempBmp        := TBitmap.Create;
TempBmp.Width  := abs(FillRect.Right - FillRect.Left);
TempBmp.Height := abs(FillRect.Bottom - FillRect.Top);

try
With TempBmp do
begin
  for i := 0 to TempBmp.Width do
    begin
      Canvas.Pen.Color:=Colors[i];
      Canvas.MoveTo(TempBmp.Width, TempBmp.Height);
      Canvas.LineTo(TempBmp.Width - i, -1);
    end;
    Canvas.Pen.Color := Colors[TempBmp.Width];
    Canvas.MoveTo(TempBmp.Width, TempBmp.Height);
    Canvas.LineTo(0, 0);
  for i := 0 to TempBmp.Height do
    begin
      Canvas.Pen.Color:=Colors[i + TempBmp.Width];
      Canvas.MoveTo(TempBmp.Width, TempBmp.Height);
      Canvas.LineTo(- 1, i);
    end;
end;
    Canvas.StretchDraw(FillRect, TempBmp);
finally
TempBmp.Free;
end;
end;

end.
